@@ -65,7 +65,7 @@ uint32_t (*convert_endian_l)(uint32_t);
 uint16_t (*convert_endian_s)(uint16_t);
 
 static int iLogLevel = 1;
-char hpFileName[] = "/tmp/hplipfaxXXXXXX";
+char hpFileName[] = "/tmp/hplipfaxLog_XXXXXX";
 
 #define TIFF_HDR_SIZE 8
 #define LITTLE_ENDIAN_MODE I
@@ -160,7 +160,30 @@ void PrintCupsHeader (cups_page_header2_t m_cupsHeader)
     BUG ("DEBUG: HPFAX - cupsPageSizeName = %s\n", m_cupsHeader.cupsPageSizeName);
 }
 
-int ProcessRasterData (cups_raster_t *cups_raster, int fdFax)
+int GetPageSizeFromString(char *string)
+{
+   int iPageSize = atoi(string);
+   if(iPageSize == 0)
+   {
+      if(strcmp(string,"Letter") ==0){
+         iPageSize = 1;
+      }
+      else if(strcmp(string,"A4") ==0){
+         iPageSize = 2;
+      }
+      else if(strcmp(string,"Legal") ==0){
+         iPageSize = 3;
+      }
+      else{
+         DBG("hpcupsfax: GetPageSizeFromString:Default Page Size is taken,ensure it is ok.\n");
+         iPageSize = 1;
+      }
+   }
+   DBG("hpcupsfax: GetPageSizeFromString: PageSize = %d\n",iPageSize);
+   return iPageSize;
+}     
+
+int  ProcessRasterData (cups_raster_t *cups_raster, int fdFax)
 {
     int                status = 0;
     unsigned int                i;
@@ -200,7 +223,8 @@ int ProcessRasterData (cups_raster_t *cups_raster, int fdFax)
             HPLIPPUTINT32 (p, 0); p += 4;                // Total number of pages in this job
             HPLIPPUTINT16 (p, cups_header.HWResolution[0]); p += 2;
             HPLIPPUTINT16 (p, cups_header.HWResolution[1]); p += 2;
-            *p++ = atoi (cups_header.cupsPageSizeName);  // Output paper size
+            BUG("ATOI Value  = %d",atoi (cups_header.cupsPageSizeName));
+            *p++ = GetPageSizeFromString(cups_header.cupsPageSizeName);  // Output paper size
             *p++ = atoi (cups_header.OutputType);        // Output quality
             *p++ = fax_encoding;                         // MH, MMR or JPEG
             p += 4;                                      // Reserved 1
@@ -578,7 +602,6 @@ int send_data_to_stdout(int fromFD)
     int     iSize, i;
     int     len;
     BYTE    *pTmp = NULL;
-    FILE    *fp = NULL;
 
     iSize = lseek (fromFD, 0, SEEK_END);
     lseek (fromFD, 0, SEEK_SET);
@@ -598,28 +621,12 @@ int send_data_to_stdout(int fromFD)
         }
     }
 
-    fp = NULL;
-    if (iLogLevel & SAVE_PCL_FILE)
-    {
-        fp = fopen ("/tmp/hpcupsfax.out", "w");
-        system ("chmod 666 /tmp/hpcupsfax.out");
-    }
-    
     while ((len = read (fromFD, pTmp, iSize)) > 0)
     {
         write (STDOUT_FILENO, pTmp, len);
-        if (iLogLevel & SAVE_PCL_FILE && fp)
-        {
-            fwrite (pTmp, 1, len, fp);
-        }
     }
     free (pTmp);
 
-    if (fp)
-    {
-        fclose (fp);
-    }
-
     return 0;
 }
 
@@ -756,9 +763,15 @@ EPILOGUE:
     {
         close (fd);
     }
+
     if (fdFax > 0)
     {
         close (fdFax);
+	if (!(iLogLevel & SAVE_PCL_FILE))
+	{
+             //Retain the intermediate file only if it is needed for debugging purpose.
+             unlink(hpFileName);
+	}
     }
 
     return status;
